==> lxqt-l10n_0.12.0.orig.tar.xz: lxqt-l10n-0.12.0/lxqt-panel/plugin-mainmenu/mainmenu_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>LXQtMainMenu</name>
    <message>
        <location filename="../../../lxqtmainmenu.cpp" line="96"/>
        <source>Search...</source>
        <translation>Pesquisar...</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenu.cpp" line="102"/>
        <source>Show/hide main menu</source>
        <translation>Mostrar/ocultar menu principal</translation>
    </message>
    <message>
        <source>Leave</source>
        <translation type="vanished">Sair</translation>
    </message>
</context>
<context>
    <name>LXQtMainMenuConfiguration</name>
    <message>
        <source>LXQt Main Menu settings</source>
        <translation type="vanished">Definições do menu principal do LXQt</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Geral</translation>
    </message>
    <message>
        <source>Show text</source>
        <translation type="vanished">Mostrar texto</translation>
    </message>
    <message>
        <source>Button text</source>
        <translation type="vanished">Texto do botão</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="14"/>
        <source>Main Menu settings</source>
        <translation>Definições do Menu principal</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="35"/>
        <source>Icon:</source>
        <translation>Ícone:</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="59"/>
        <source>Button text:</source>
        <translation>Texto do botão:</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="76"/>
        <source>Custom font size:</source>
        <translation>Tipo de letra personalizado:</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="86"/>
        <source> pt</source>
        <translation> pt</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="105"/>
        <source>Menu file</source>
        <translation>Ficheiro de menu</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="111"/>
        <source>Menu file:</source>
        <translation>Ficheiro de menu:</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="156"/>
        <source>Search</source>
        <translation>Pesquisar</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="162"/>
        <source>max. item width:</source>
        <translation>Largura máxima do item:</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="169"/>
        <source>Show matching entries:</source>
        <translation>Mostrar entradas coincidentes:</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="183"/>
        <source>Maximum visible items:</source>
        <translation>N.º máximo de itens visíveis:</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="190"/>
        <source>Filter menu entries</source>
        <translation>Filtrar entradas de menu</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="197"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="210"/>
        <source>Hide menu entries while searching</source>
        <translation>Ocultar entradas de menu ao pesquisar</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="217"/>
        <source>Clear search upon showing menu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>...</source>
        <translation type="vanished">...</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="127"/>
        <source>Keyboard Shortcut</source>
        <translation>Atalho de teclado</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="146"/>
        <source>Click the button to record shortcut:</source>
        <translation>Clique no botão para registar o atalho:</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.cpp" line="71"/>
        <source>Reset</source>
        <translation>Repor</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.cpp" line="165"/>
        <source>Choose icon file</source>
        <translation>Escolher ficheiro de ícone</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.cpp" line="167"/>
        <source>Images (*.svg *.png)</source>
        <translation>Imagens (*.svg *.png)</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.cpp" line="179"/>
        <source>Choose menu file</source>
        <translation>Escolher ficheiro de menu</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.cpp" line="181"/>
        <source>Menu files (*.menu)</source>
        <translation>Ficheiros de menu (*.menu)</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.13.0.orig.tar.xz: lxqt-l10n-0.13.0/lxqt-panel/plugin-mainmenu/mainmenu_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>LXQtMainMenu</name>
    <message>
        <location filename="../../../lxqtmainmenu.cpp" line="96"/>
        <source>Search...</source>
        <translation>Pesquisar...</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenu.cpp" line="102"/>
        <source>Show/hide main menu</source>
        <translation>Mostrar/ocultar menu principal</translation>
    </message>
    <message>
        <source>Leave</source>
        <translation type="vanished">Sair</translation>
    </message>
</context>
<context>
    <name>LXQtMainMenuConfiguration</name>
    <message>
        <source>LXQt Main Menu settings</source>
        <translation type="vanished">Definições do menu principal do LXQt</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Geral</translation>
    </message>
    <message>
        <source>Show text</source>
        <translation type="vanished">Mostrar texto</translation>
    </message>
    <message>
        <source>Button text</source>
        <translation type="vanished">Texto do botão</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="14"/>
        <source>Main Menu settings</source>
        <translation>Definições do Menu principal</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="35"/>
        <source>Icon:</source>
        <translation>Ícone:</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="59"/>
        <source>Button text:</source>
        <translation>Texto do botão:</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="76"/>
        <source>Custom font size:</source>
        <translation>Tipo de letra personalizado:</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="86"/>
        <source> pt</source>
        <translation> pt</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="105"/>
        <source>Menu file</source>
        <translation>Ficheiro de menu</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="111"/>
        <source>Menu file:</source>
        <translation>Ficheiro de menu:</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="156"/>
        <source>Search</source>
        <translation>Pesquisar</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="162"/>
        <source>max. item width:</source>
        <translation>Largura máxima do item:</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="169"/>
        <source>Show matching entries:</source>
        <translation>Mostrar entradas coincidentes:</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="183"/>
        <source>Maximum visible items:</source>
        <translation>N.º máximo de itens visíveis:</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="190"/>
        <source>Filter menu entries</source>
        <translation>Filtrar entradas de menu</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="197"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="210"/>
        <source>Hide menu entries while searching</source>
        <translation>Ocultar entradas de menu ao pesquisar</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="217"/>
        <source>Clear search upon showing menu</source>
        <translation>Limpar pesquisa ao mostrar o menu</translation>
    </message>
    <message>
        <source>...</source>
        <translation type="vanished">...</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="127"/>
        <source>Keyboard Shortcut</source>
        <translation>Atalho de teclado</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.ui" line="146"/>
        <source>Click the button to record shortcut:</source>
        <translation>Clique no botão para registar o atalho:</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.cpp" line="71"/>
        <source>Reset</source>
        <translation>Repor</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.cpp" line="165"/>
        <source>Choose icon file</source>
        <translation>Escolher ficheiro de ícone</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.cpp" line="167"/>
        <source>Images (*.svg *.png)</source>
        <translation>Imagens (*.svg *.png)</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.cpp" line="179"/>
        <source>Choose menu file</source>
        <translation>Escolher ficheiro de menu</translation>
    </message>
    <message>
        <location filename="../../../lxqtmainmenuconfiguration.cpp" line="181"/>
        <source>Menu files (*.menu)</source>
        <translation>Ficheiros de menu (*.menu)</translation>
    </message>
</context>
</TS>
